--- a/iaupdate/IAD/ui/inc/iaupdateengine.h Fri Jun 11 13:45:18 2010 +0300
+++ b/iaupdate/IAD/ui/inc/iaupdateengine.h Thu Jun 24 12:37:54 2010 +0300
@@ -34,7 +34,7 @@
class MIAUpdateNode;
class MIAUpdateFwNode;
class CEikonEnv;
-class RCmManagerExt;
+class RCmManager;
class CIdle;
class HbAction;
class IAUpdateResultsDialog;
@@ -150,6 +150,13 @@
* @param aError Error code
*/
void HandleLeaveErrorWithoutLeave( TInt aError );
+
+ /**
+ Called when UI to be redrawn during update process
+ *
+ * @param aError Error code
+ */
+ void RefreshUI();
/**
* Called when async update list refresh is completed
@@ -199,24 +206,24 @@
/**
* Choose a usable IAP from all SNAPs
*
* @param aCmManagerExt handle of connection manager
*/
- uint GetBestIAPInAllSNAPsL( RCmManagerExt& aCmManagerExt );
+ uint GetBestIAPInAllSNAPsL( RCmManager& aCmManager );
/**
* Choose a usable IAP from Internet SNAP
*
* @param aCmManagerExt handle of connection manager
*/
- uint GetBestIAPInInternetSNAPL( RCmManagerExt& aCmManagerExt );
+ uint GetBestIAPInInternetSNAPL( RCmManager& aCmManager );
/**
* Choose the best IAP under the given SNAP
*
* @param aCmManagerExt handle of connection manager
* @param aSNAP SNAP ID
*/
- uint GetBestIAPInThisSNAPL( RCmManagerExt& aCmManagerExt, uint aSNAP = 0);
+ uint GetBestIAPInThisSNAPL( RCmManager& aCmManager, uint aSNAP = 0);
/**
* Shows update query dialog (now/later)
@@ -241,7 +248,7 @@
*/
static TInt AutomaticCheckCallbackL( TAny* aPtr );
- void DoPossibleApplicationClose();
+ bool DoPossibleApplicationClose();
@@ -199,24 +206,24 @@
* Choose a usable IAP from all SNAPs
*
- * @param aCmManagerExt handle of connection manager
+ * @param aCmManager handle of connection manager
*/
@@ -199,24 +206,24 @@
* Choose a usable IAP from Internet SNAP
*
- * @param aCmManagerExt handle of connection manager
+ * @param aCmManager handle of connection manager
*/
@@ -199,24 +206,24 @@
* Choose the best IAP under the given SNAP
*
- * @param aCmManagerExt handle of connection manager
+ * @param aCmManager handle of connection manager
* @param aSNAP SNAP ID
*/